@@ -8,6 +8,6 @@ class FrontendView:
     @action(detail=False, methods=['get'], url_path='current', url_name='current')
     def current(self, request, *args, **kwargs):
         user_id = jwt_get_userid_handler(request.auth)
-        queryset = self.model_class.objects.get(pk=user_id)
+        queryset = self.model_class.objects.filter(pk=user_id).first()
         serializer = self.get_serializer(queryset)
         return Response(serializer.data)
