@@ -41,10 +41,11 @@ class WeChatLoginWebSocketView(APIView):
     permission_classes = ()
 
     def get(self, request, *args, **kwargs):
-        scene_str = ''
+        scene_str = request.query_params.get('scene_str', '')
         queryset = WeChatLogin.objects.filter(scene_str=scene_str).first()
-        user_queryset = User.objects.filter(openid=queryset.openid).first()
-        token = jwt_create_token_wechat(
-            openid=user_queryset.openid, unionid=user_queryset.unionid, user_id=user_queryset.pk, wechat_id=user_queryset.wechat_id)
-        send(scene_str, {'token': token})
-        return Response()
+        if queryset and queryset.openid:
+            user_queryset = User.objects.filter(openid=queryset.openid).first()
+            token = jwt_create_token_wechat(
+                openid=user_queryset.openid, unionid=user_queryset.unionid, user_id=user_queryset.pk, wechat_id=user_queryset.wechat_id)
+            send(scene_str, {'token': token})
+            return Response()
